/*
 * (c) Copyright 2003 M. van Meegen
 * All Rights Reserved.
 * Sourcecode is licensed under Mozilla Public License 1.1
 */
package edu.virginia.cs.escjava;

import java.util.MissingResourceException;
import java.util.ResourceBundle;

import org.eclipse.core.resources.IWorkspace;
import org.eclipse.core.resources.ResourcesPlugin;
import org.eclipse.core.runtime.IPluginDescriptor;
import org.eclipse.core.runtime.Status;
import org.eclipse.jface.preference.IPreferenceStore;
import org.eclipse.ui.plugin.AbstractUIPlugin;

/**
 * The main plugin class to be used in the desktop.
 * @author Marco van Meegen
 */
public class EscjavaPlugin extends AbstractUIPlugin {
	/** The shared instance */
	private static EscjavaPlugin plugin;
	/** Resource bundle */
	private ResourceBundle resourceBundle;
	

	public static final String ESCJAVA_LOCATION_PREFERENCE = "escjava_loc";

	public static final String DEFAULT_ESCJAVA_LOCATION = "C:\\Program Files\\Java\\escjava\\bin\\escjava.bat";

	/**
	 * The constructor.
	 * @param descriptor descriptor
	 */
	public EscjavaPlugin(IPluginDescriptor descriptor) {
		super(descriptor);
		plugin = this;
		try {
			resourceBundle = ResourceBundle.getBundle("edu.virginia.cs.escjava.escjavaPluginResources");
		} catch (MissingResourceException x) {
			resourceBundle = null;
		}
	}

	/**
	 * @return the shared instance.
	 */
	public static EscjavaPlugin getDefault() {
		return plugin;
	}

	/**
	 * @return the workspace instance.
	 */
	public static IWorkspace getWorkspace() {
		return ResourcesPlugin.getWorkspace();
	}

	protected void initializeDefaultPreferences(IPreferenceStore store) {
		store.setDefault(ESCJAVA_LOCATION_PREFERENCE, DEFAULT_ESCJAVA_LOCATION);
		
	}
	/**
	 * @return the string from the plugin's resource bundle,
	 * or 'key' if not found.
	 * @param key key to search
	 */
	public static String getResourceString(String key) {
		ResourceBundle bundle = EscjavaPlugin.getDefault().getResourceBundle();
		try {
			return bundle.getString(key);
		} catch (MissingResourceException e) {
			return key;
		}
	}

	/**
	 * @return the plugin's resource bundle,
	 */
	public ResourceBundle getResourceBundle() {
		return resourceBundle;
	}

	/**
	 * logs message on plugin log
	 * @param message string to log
	 * @param severity severity from class Status
	 */
	public static void log(String message, int severity) {
		Status s = new Status(severity, getDefault().getDescriptor().getUniqueIdentifier(),
			999, message, null);
		getDefault().getLog().log(s);
	}

	/**
	 * logs exception on plugin log
	 * @param ex exception to log
	 */
	public static void log(Throwable ex) {
		Status s = new Status(Status.ERROR, getDefault().getDescriptor().getUniqueIdentifier(),
		888, ex.getLocalizedMessage(), ex);
		getDefault().getLog().log(s);
	}

	/**
	 * logs exception with message on plugin log
	 * @param message message to log
	 * @param ex exception to log
	 */
	public static void log(String message, Throwable ex) {
		Status s = new Status(Status.ERROR, getDefault().getDescriptor().getUniqueIdentifier(),
		777, message, ex);
		getDefault().getLog().log(s);
	}

	/** checkclipse plugin id */
	public static final String CHECKCLIPSE_ID = "edu.virginia.cs.escjava";

	/** checkclipse marker id */
	public static final String CHECKCLIPSE_MARKER_ID = CHECKCLIPSE_ID + ".EscjavaMarker";

	/** checkclipse builder id */
	public static final String CHECKCLIPSE_BUILDER_ID = CHECKCLIPSE_ID + ".EscjavaBuilder";

	/** checkclipse nature id */
	public static final String CHECKCLIPSE_NATURE_ID = CHECKCLIPSE_ID + ".EscjavaNature";

}
