/*
 * (c) Copyright 2002 M. van Meegen
 * All Rights Reserved.
 * Sourcecode is licensed under Mozilla Public License 1.1
 */
package edu.virginia.cs.escjava;

import java.io.ByteArrayInputStream;
import java.io.ByteArrayOutputStream;
import java.io.IOException;
import java.io.InputStream;

import org.eclipse.core.resources.IFile;
import org.eclipse.core.resources.IProject;
import org.eclipse.core.runtime.CoreException;
import org.eclipse.jface.preference.PreferenceStore;



/**
 * preference store extension to be able to use field editors in property page
 * @author Marco van Meegen
 */
public class EscjavaPreferenceStore extends PreferenceStore {

	/** project the preference store is associated with */
	private IProject project = null;

	/**
	 * create a preference store without associated project.
	 * Project must be set before store can be used !
	 */
	public EscjavaPreferenceStore() {
		this(null);
	}

	/**
	 * create a preference store associated with the project.
	 * @param project project where prefs file is maintained
	 */
	public EscjavaPreferenceStore(IProject project) {
		setProject(project);
		if (project != null) {
			try {
				load();
			} catch (IOException ex) {
				EscjavaPlugin.log("project properties: load failed", ex);
			}
		}
	}

	/** 
	 * overridden to avoid saving of dummy store
	 * @see org.eclipse.jface.preference.IPersistentPreferenceStore#save()
	 */
	public void save() throws IOException {
		// does nothing; values are saved in performOK()

		IFile f = project.getFile(".escjava");
		ByteArrayOutputStream out = null;
		try {
			if (!f.exists()) {
				// create it
				f.create(null, true, null);
			}
			out = new ByteArrayOutputStream(); 
			// out = new FileOutputStream(f.getLocation().toString());
			save(out, null);
			out.flush();
			f.setContents(new ByteArrayInputStream(out.toByteArray()), true, false, null);
			out.close();
			out = null;
		} catch (CoreException ex) {
			EscjavaPlugin.log("project properties: save failed", ex);
		} finally {
			if (out != null) {
				out.close();
			}
		}

	}

	/** 
	 * overridden to load preferences from .checkclipse file in associated project
	 * @see org.eclipse.jface.preference.PreferenceStore#load()
	 */
	public void load() throws IOException {
		IFile f = project.getFile(".escjava");
		if (f.exists())	{
			InputStream in = null;
			try {
				in = f.getContents();
				load(in);
			} catch (Throwable ex) {
				EscjavaPlugin.log("project properties: load failed", ex);
				throw new IOException(".checkclipse could not be loaded: " + ex.getLocalizedMessage());
			} finally {
				if (in != null) {
					in.close();
				}
			}
		}
	}

	/** sets the project where preferences are maintained for.
	 * must be set prior to open/save operations
	 * @param project project
	 */
	public void setProject(IProject project) {
		this.project = project; 	
	}
}